@@ -1,5 +1,6 @@
 use crypto_market_type::MarketType;
 use crypto_msg_type::MessageType;
+use crypto_pair::get_market_type;
 
 use crate::exchanges::utils::{calc_quantity_and_volume, http_get};
 use crate::{FundingRateMsg, Order, OrderBookMsg, TradeMsg, TradeSide};
@@ -485,56 +486,6 @@ pub(crate) fn get_msg_type(msg: &str) -> MessageType {
     }
 }
 
-// Copied from crypto-markets/tests/bitmex.rs
-pub fn get_market_type_from_symbol(symbol: &str) -> MarketType {
-    let is_future = {
-        let date = &symbol[(symbol.len() - 2)..];
-        date.parse::<i64>().is_ok()
-    };
-    let real_symbol = if is_future {
-        &symbol[..(symbol.len() - 3)]
-    } else {
-        symbol
-    };
-    // 0, linear; 1, inverse; 2, quanto
-    let linear_inverse_quanto = if real_symbol.ends_with("USDT") {
-        0
-    } else if real_symbol.starts_with("XBT") {
-        1
-    } else if real_symbol.ends_with("USD") || real_symbol.ends_with("EUR") {
-        2
-    } else {
-        // Settled in XBT, quoted in XBT
-        debug_assert_eq!(symbol.len(), 6);
-        0
-    };
-
-    match linear_inverse_quanto {
-        0 => {
-            if is_future {
-                MarketType::LinearFuture
-            } else {
-                MarketType::LinearSwap
-            }
-        }
-        1 => {
-            if is_future {
-                MarketType::InverseFuture
-            } else {
-                MarketType::InverseSwap
-            }
-        }
-        2 => {
-            if is_future {
-                MarketType::QuantoFuture
-            } else {
-                MarketType::QuantoSwap
-            }
-        }
-        _ => panic!("Impossible {}", symbol),
-    }
-}
-
 pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<TradeMsg>> {
     let ws_msg = serde_json::from_str::<WebsocketMsg<RawTradeMsg>>(msg)?;
     let raw_trades = ws_msg.data;
@@ -544,7 +495,7 @@ pub(crate) fn parse_trade(market_type: MarketType, msg: &str) -> Result<Vec<Trad
             // assert_eq!(raw_trade.foreignNotional, raw_trade.homeNotional * raw_trade.price); // tiny diff actually exists
             let timestamp = DateTime::parse_from_rfc3339(&raw_trade.timestamp).unwrap();
             let market_type = if market_type == MarketType::Unknown {
-                get_market_type_from_symbol(&raw_trade.symbol)
+                get_market_type(&raw_trade.symbol, EXCHANGE_NAME, None)
             } else {
                 market_type
             };
@@ -586,7 +537,7 @@ pub(crate) fn parse_funding_rate(
         .map(|raw_msg| {
             let settlement_time = DateTime::parse_from_rfc3339(&raw_msg.timestamp).unwrap();
             let market_type = if market_type == MarketType::Unknown {
-                get_market_type_from_symbol(&raw_msg.symbol)
+                get_market_type(&raw_msg.symbol, EXCHANGE_NAME, None)
             } else {
                 market_type
             };
@@ -642,7 +593,7 @@ pub(crate) fn parse_l2(
     let symbol = ws_msg.data[0].symbol.clone();
     let pair = crypto_pair::normalize_pair(&symbol, EXCHANGE_NAME).unwrap();
     let market_type = if market_type == MarketType::Unknown {
-        get_market_type_from_symbol(&symbol)
+        get_market_type(&symbol, EXCHANGE_NAME, None)
     } else {
         market_type
     };
